terminal-render.util


add-charclj

(add-char m c x y fg bg)

A convenience function for working with terminal inputs. Adds a character (char or int) to a terminal at a specific point. If fg or bg is nil, the existing fg or bg is used.

A convenience function for working with terminal inputs.
Adds a character (char or int) to a terminal at a specific point.
If fg or bg is nil, the existing fg or bg is used.
sourceraw docstring

add-stringclj

(add-string m s x y fg bg)

A convenience function for working with terminal inputs. Adds a string to a terminal starting at a specific point. If fg or bg is nil, the existing fg or bg is used.

A convenience function for working with terminal inputs.
Adds a string to a terminal starting at a specific point.
If fg or bg is nil, the existing fg or bg is used.
sourceraw docstring

blank-terminalclj

(blank-terminal)

A convenience function for working with terminal inputs.

A convenience function for working with terminal inputs.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries