(add-char m c x y fg bg)A convenience function for working with terminal inputs. Adds a character (char or int) to a terminal at a specific point. If fg or bg is nil, the existing fg or bg is used.
A convenience function for working with terminal inputs. Adds a character (char or int) to a terminal at a specific point. If fg or bg is nil, the existing fg or bg is used.
(add-string m s x y fg bg)A convenience function for working with terminal inputs. Adds a string to a terminal starting at a specific point. If fg or bg is nil, the existing fg or bg is used.
A convenience function for working with terminal inputs. Adds a string to a terminal starting at a specific point. If fg or bg is nil, the existing fg or bg is used.
(blank-terminal)A convenience function for working with terminal inputs.
A convenience function for working with terminal inputs.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |